# Pylon changelog

## [0.1.8] - 2026-03-03
- Updated connector definition (YAML version 0.1.3)
- Source commit: 258f32e0
- SDK version: 0.1.0

## [0.1.7] - 2026-02-27
- Updated connector definition (YAML version 0.1.3)
- Source commit: a735c402
- SDK version: 0.1.0

## [0.1.6] - 2026-02-27
- Updated connector definition (YAML version 0.1.3)
- Source commit: 7bd29cad
- SDK version: 0.1.0

## [0.1.5] - 2026-02-27
- Updated connector definition (YAML version 0.1.3)
- Source commit: 39690c8e
- SDK version: 0.1.0

## [0.1.4] - 2026-02-26
- Updated connector definition (YAML version 0.1.3)
- Source commit: 9072a725
- SDK version: 0.1.0

## [0.1.3] - 2026-02-23
- Updated connector definition (YAML version 0.1.3)
- Source commit: 62fbfc1f
- SDK version: 0.1.0

## [0.1.2] - 2026-02-20
- Updated connector definition (YAML version 0.1.3)
- Source commit: e9e5b384
- SDK version: 0.1.0

## [0.1.1] - 2026-02-20
- Updated connector definition (YAML version 0.1.2)
- Source commit: 8177d883
- SDK version: 0.1.0

## [0.1.0] - 2026-02-20
- Updated connector definition (YAML version 0.1.1)
- Source commit: dd1a513d
- SDK version: 0.1.0
